summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorVraj Mohan <r.vrajmohan@gmail.com>2013-11-14 10:42:35 -0500
committerVraj Mohan <r.vrajmohan@gmail.com>2013-11-14 14:31:37 -0500
commitfc64812bad75fc5ecbfc95d715ed526994dc61ec (patch)
tree6cfe784b155f44c250a7fb78ae6a9ba5d1cb99a1
parentd55193ce49af701fc522e868599df4c26f185e2b (diff)
downloadsqlalchemy-fc64812bad75fc5ecbfc95d715ed526994dc61ec.tar.gz
Fix references to exceptions
-rw-r--r--doc/build/orm/mapper_config.rst2
-rw-r--r--lib/sqlalchemy/exc.py6
-rw-r--r--lib/sqlalchemy/orm/base.py4
3 files changed, 6 insertions, 6 deletions
diff --git a/doc/build/orm/mapper_config.rst b/doc/build/orm/mapper_config.rst
index 7749b9314..9cd9abaca 100644
--- a/doc/build/orm/mapper_config.rst
+++ b/doc/build/orm/mapper_config.rst
@@ -1337,7 +1337,7 @@ If a transaction elsewhere has modifed the row independently, this version id
will no longer match, and the UPDATE statement will report that no rows matched;
this is the condition that SQLAlchemy tests, that exactly one row matched our
UPDATE (or DELETE) statement. If zero rows match, that indicates our version
-of the data is stale, and a :class:`.StaleDataError` is raised.
+of the data is stale, and a :exc:`.StaleDataError` is raised.
.. _custom_version_counter:
diff --git a/lib/sqlalchemy/orm/base.py b/lib/sqlalchemy/orm/base.py
index 7e56b0228..22c92b7c1 100644
--- a/lib/sqlalchemy/orm/base.py
+++ b/lib/sqlalchemy/orm/base.py
@@ -338,8 +338,8 @@ def class_mapper(class_, configure=True):
"""Given a class, return the primary :class:`.Mapper` associated
with the key.
- Raises :class:`.UnmappedClassError` if no mapping is configured
- on the given class, or :class:`.ArgumentError` if a non-class
+ Raises :exc:`.UnmappedClassError` if no mapping is configured
+ on the given class, or :exc:`.ArgumentError` if a non-class
object is passed.
Equivalent functionality is available via the :func:`.inspect`
diff --git a/lib/sqlalchemy/exc.py b/lib/sqlalchemy/exc.py
index 7ebdc3983..3c0c6c365 100644
--- a/lib/sqlalchemy/exc.py
+++ b/lib/sqlalchemy/exc.py
@@ -6,9 +6,9 @@
"""Exceptions used with SQLAlchemy.
-The base exception class is :class:`.SQLAlchemyError`. Exceptions which are
+The base exception class is :exc:`.SQLAlchemyError`. Exceptions which are
raised as a result of DBAPI exceptions are all subclasses of
-:class:`.DBAPIError`.
+:exc:`.DBAPIError`.
"""
@@ -169,7 +169,7 @@ class UnboundExecutionError(InvalidRequestError):
class DontWrapMixin(object):
"""A mixin class which, when applied to a user-defined Exception class,
will not be wrapped inside of :class:`.StatementError` if the error is
emitted within the process of executing a statement.
E.g.::
@@ -169,7 +169,7 @@ class UnboundExecutionError(InvalidRequestError):
class DontWrapMixin(object):
"""A mixin class which, when applied to a user-defined Exception class,
- will not be wrapped inside of :class:`.StatementError` if the error is
+ will not be wrapped inside of :exc:`.StatementError` if the error is
emitted within the process of executing a statement.
E.g.::